@@ -52,7 +52,7 @@
 				/* X and server generic header files */
 #include "xf86.h"
 #include "windowstr.h"
-#include "xf86PciInfo.h"
+#include "atipciids.h"
 
 #include "shadowfb.h"
 				/* GLX/DRI/DRM definitions */
@@ -247,7 +247,7 @@ static Bool R128InitVisualConfigs(ScreenPtr pScreen)
 		}
 		pConfigs[i].auxBuffers         = 0;
 		pConfigs[i].level              = 0;
-		if (accum || stencil) {
+		if (accum) {
 		   pConfigs[i].visualRating    = GLX_SLOW_CONFIG;
 		} else {
 		   pConfigs[i].visualRating    = GLX_NONE;
